@@ -41,4 +41,7 @@ class TimeActivity(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedT
         self.EmployeeRef = None
         self.ItemRef = None
         self.ClassRef = None
-        self.AttachableRef = None
\ No newline at end of file
+        self.AttachableRef = None
+
+    def __str__(self):
+        return self.NameOf
